#' Biomarker Responses of the Blue Mussels to Organic UV Filters
#'
#' @encoding UTF-8
#'
#' @source Pham, D. N., Sokolov, E. P., Falfushynska, H., & Sokolova, I. M.
#'   (2022). Gone with sunscreens: Responses of blue mussels (Mytilus edulis) to
#'   a wide concentration range of a UV filter ensulizole. Chemosphere, 309,
#'   136736. \doi{10.1016/j.chemosphere.2022.136736}.
#' @name ensulizole
"mussel_SoS"

#' @rdname ensulizole
"mussel_gill"
#' @rdname ensulizole
"mussel_digest"
